# Warre Client

Client for Nectar Reservation System Warre
https://github.com/NeCTAR-RC/warre/

## Common openstack CLI Commands

* `openstack warre flavor list`

* `openstack warre flavor show <Flavor-ID>`

* `openstack warre reservation create --start  '2021-04-23 05:10' --end '2021-04-23 06:00' <Flavor-ID>

* `openstack warre reservation list`

* `openstack warre reservation delete <Reservation-ID>`
